# frozen_string_literal: true

class HandleOfferEligibleNbJob < ActiveJob::Base
 
  queue_as :x_hermes_eligibility
  unique :until_executed

  def perform(offer_id, request_orientation_changes)
    # @offer_id: String => target offer
    # @request_id: String => target request
    # @request_orientation_changes: |v Hash v|
    #   {
    #     priority_public: 1,
    #     single_parent: -1,
    #     ... ,
    #     entities: {
    #       id1: -1,
    #       id2: 1,
    #       ...
    #     }
    #   }
    if (offer = Hermes::HousingOffer.find_by(id: offer_id))
      increment_rules = request_orientation_changes.each_with_object({}) do |(key, inc), h|
        if [:entities, 'entities'].include?(key)
          inc.each do |entity_id, true_inc|
            h["#{key}.#{entity_id}".to_sym] = true_inc unless entity_id.blank?
          end
        elsif Hermes::HousingOffer::ORIENTATION_BOOLS.include?(key)
          h[key.to_sym] = inc
        end
        h
      end

      increment_rules = increment_rules.each_with_object({}) do |(key, val), h|
        h["eligible_requests_nb_detailed.#{key}".to_sym] = val
      end
      offer.inc(**increment_rules)
      offer.set(updated_at: DateTime.current)
    end
  end
end
