require 'rails_helper'
require 'json'
require 'csv'

module Hermes
	RSpec.describe Hermes::Admin::UntensedAreasController, type: :controller do
		routes { Hermes::Engine.routes }

		describe "index" do
			let(:user) { create :user, roles: ['Administrator'] }

			before do                
				sign_in user
				get('index')
			end

			it 'renders index view' do
				expect(response).to render_template(:index)
			end
		end 

		describe "testing file download" do
			let(:user) { create :user, roles: ['Administrator'] }

			before do
				sign_in user
				get('download_csv')
			end

			it "does download" do
				expect(response.header["Content-Type"]).to eq "application/csv"
			end
		end 

		describe "testing update" do
			let(:user) { create :user, roles: ['Administrator'] }
			let(:area) { create :untensed_area, user: user, insee_code: '13', department: 'Bouches du rhone' }

			before do
				sign_in user
				put :update, id: area.id, untensed_area: { insee_code: '84', department: 'Vaucluse' }
			end

			it "should update area data" do
				expect(area.reload.insee_code).to eq '84'
				expect(area.reload.department).to eq 'Vaucluse'
			end
		end 

		describe "testing destroy" do
			let(:user) { create :user, roles: ['Administrator'] }
			let!(:area) { create :untensed_area, user: user, insee_code: '13', department: 'Bouches du rhone' }

			before do
				sign_in user
			end

			it "should delete area" do
				expect { 
					delete :destroy, id: area.id
				}.to change(Hermes::UntensedArea, :count).by(-1)
			end
		end 
	end 
end 
